@@ -13,7 +13,7 @@
 ;;; GNU General Public License for more details.
 
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
+;;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 (in-package :consfigurator)
 (named-readtables:in-readtable :consfigurator)
@@ -500,8 +500,6 @@ UPLOAD-ALL-PREREQUISITE-DATA.")
        ,@(loop for system in (propspec-systems (host-propspec *host*))
                collect `(asdf:load-system ,system)))))
 
-(defpackage :consfigurator.cl-user (:use #:cl))
-
 (defgeneric continue-deploy*-program (remaining-connections asdf-requirements)
   (:documentation
    "Return a program to complete the work of an enclosing call to DEPLOY*.
@@ -595,7 +593,7 @@ Preprocessing must occur in the root Lisp."))
                     ;; e.g. by the user's runtime config for the root Lisp.
                     ;; This way, all symbols except those from COMMON-LISP
                     ;; should be printed qualified by their package names.
-                    (*package* (find-package :consfigurator.cl-user)))
+                    (*package* (find-package :cl)))
                 ;; need line breaks in between so that packages exist before we
                 ;; try to have remote Lisp read sexps containing symbols from
                 ;; those packages
