@@ -699,7 +699,8 @@
                     #:debian-live-iso-built.
                     #:host-logical-volumes-exist
 
-                    #:volumes))
+                    #:volumes
+                    #:get-partition-uuid))
 
   (package :consfigurator.property.fstab
            (:use #:consfigurator.property.disk)
@@ -718,6 +719,7 @@
                              (#:file  #:consfigurator.property.file)
                              (#:disk  #:consfigurator.property.disk))
            (:export #:volume-to-entry
+                    #:has-entries
                     #:has-entries-for-opened-volumes))
 
   (package :consfigurator.property.gnupg
@@ -979,10 +981,13 @@
                     #:configured-from-parent))
 
   (package :consfigurator.property.swap
-           (:local-nicknames (#:cmd          #:consfigurator.property.cmd)
+           (:local-nicknames (#:file         #:consfigurator.property.file)
+                             (#:cmd          #:consfigurator.property.cmd)
                              (#:fstab        #:consfigurator.property.fstab)
-                             (#:os           #:consfigurator.property.os))
-           (:export #:has-swap-file))
+                             (#:os           #:consfigurator.property.os)
+                             (#:disk         #:consfigurator.property.disk))
+           (:export #:has-swap-file
+                    #:resume-configured))
 
   (package :consfigurator.property.lxc
            (:use #:consfigurator.util.linux-namespace #:cffi)
